Crate ligo_hires_gps_time

Crate ligo_hires_gps_time 

There are 230 · 59 “pips” in one second. We coin the name “pip” and introduce this novel reoslution here for the first time.

This library provides types for tracking time in pips as integer.

Because all, or almost all LIGO/VIRGO channels, except for minute trends, have a sample period that is a power of two or ten, this allows exact representation of the time of every sample of every channel

The exception is LIGO minute trends which have a sample period of 60 seconds, but these points are also exactly represented.

Re-exports

pub use units::PipInstant;
pub use units::PipDuration;
pub use units::ThumpInstant;
pub use units::ThumpDuration;

Modules

units